@@ -1,16 +1,26 @@
+# vim: ts=2 sw=2 expandtab
 use strict;
 
 use lib qw(./mylib ../mylib);
 use Test::More tests => 38;
 
 sub POE::Kernel::ASSERT_DEFAULT () { 1 }
-sub POE::Kernel::TRACE_DEFAULT  () { 1 }
-sub POE::Kernel::TRACE_FILENAME () { "./test-output.err" }
+
+BEGIN {
+  package POE::Kernel;
+  use constant TRACE_DEFAULT => exists($INC{'Devel/Cover.pm'});
+}
 
 BEGIN { use_ok("POE") }
 
 sub BOGUS_SESSION () { 31415 }
 
+my $baseline_event = 0;
+$baseline_event++ if POE::Kernel::TRACE_STATISTICS; # stat poll event
+
+my $baseline_refcount = 0;
+$baseline_refcount += 2 if POE::Kernel::TRACE_STATISTICS; # stat poll event
+
 # This subsystem is still very closely tied to POE::Kernel, so we
 # can't call initialize ourselves.  TODO Separate it, if possible,
 # enough to make this feasible.
@@ -30,37 +40,40 @@ sub BOGUS_SESSION () { 31415 }
   );
 
   # Event 1 is the kernel's performance poll timer.
-  ok($event_id == 2, "first user created event is ID $event_id (should be 3)");
+  is(
+    $event_id, $baseline_event + 1,
+    "first user created event has correct ID"
+  );
 
   # Kernel should therefore have two events due.  A nonexistent
   # session should have zero.
 
-  ok(
-    $poe_kernel->_data_ev_get_count_from($poe_kernel) == 2,
-    "POE::Kernel has enqueued three events"
+  is(
+    $poe_kernel->_data_ev_get_count_from($poe_kernel), $baseline_event + 1,
+    "POE::Kernel has enqueued correct number of events"
   );
 
-  ok(
-    $poe_kernel->_data_ev_get_count_to($poe_kernel) == 2,
+  is(
+    $poe_kernel->_data_ev_get_count_to($poe_kernel), $baseline_event + 1,
     "POE::Kernel has three events enqueued for it"
   );
 
-  ok(
-    $poe_kernel->_data_ev_get_count_from("nothing") == 0,
+  is(
+    $poe_kernel->_data_ev_get_count_from("nothing"), 0,
     "unknown session has enqueued no events"
   );
 
-  ok(
-    $poe_kernel->_data_ev_get_count_to("nothing") == 0,
+  is(
+    $poe_kernel->_data_ev_get_count_to("nothing"), 0,
     "unknown session has no events enqueued for it"
   );
 
   # Performance timer (x2), session, and from/to for the event we
   # enqueued.
 
-  ok(
-    $poe_kernel->_data_ses_refcount($poe_kernel) == 4,
-    "POE::Kernel's reference count is five"
+  is(
+    $poe_kernel->_data_ses_refcount($poe_kernel), $baseline_refcount + 2,
+    "POE::Kernel's timer count is correct"
   );
 }
 
@@ -112,9 +125,9 @@ check_references(
     $poe_kernel, $ids[1]
   );
 
-  ok($time == 2, "removed event has the expected due time");
-  ok(
-    $event->[POE::Kernel::EV_NAME] eq "timer",
+  is($time, 2, "removed event has the expected due time");
+  is(
+    $event->[POE::Kernel::EV_NAME], "timer",
     "removed event has the expected name"
   );
 
@@ -144,13 +157,13 @@ check_references(
   $poe_kernel, 0, "after removing timers from a bogus session"
 );
 
-ok(
-  $poe_kernel->_data_ev_get_count_from(BOGUS_SESSION) == 0,
+is(
+  $poe_kernel->_data_ev_get_count_from(BOGUS_SESSION), 0,
   "bogus session has created no events"
 );
 
-ok(
-  $poe_kernel->_data_ev_get_count_to(BOGUS_SESSION) == 0,
+is(
+  $poe_kernel->_data_ev_get_count_to(BOGUS_SESSION), 0,
   "bogus session has no events enqueued for it"
 );
 
@@ -166,20 +179,20 @@ check_references(
   # session.
 
   my @removed = $poe_kernel->_data_ev_clear_alarm_by_session(8675309);
-  ok(@removed == 0, "didn't remove alarm from nonexistent session");
+  is(@removed, 0, "didn't remove alarm from nonexistent session");
 }
 
 { # Remove the last of the timers.  The Kernel session is the only
   # reference left for it.
 
   my @removed = $poe_kernel->_data_ev_clear_alarm_by_session($poe_kernel);
-  ok(@removed == 1, "removed the last alarm successfully");
+  is(@removed, 1, "removed the last alarm successfully");
 
   # Verify that the removed timer is the correct one.  We still have
   # the signal polling timer around there somewhere.
   my ($removed_name, $removed_time, $removed_args) = @{$removed[0]};
-  ok($removed_name eq "other-timer", "last alarm had the corrent name");
-  ok($removed_time == 4, "last alarm had the corrent due time");
+  is($removed_name, "other-timer", "last alarm had the corrent name");
+  is($removed_time, 4, "last alarm had the corrent due time");
 
   check_references(
     $poe_kernel, 0, "after clearing all alarms for a session"
@@ -216,7 +229,8 @@ $poe_kernel->_data_ev_clear_session($poe_kernel);
 
   my $session = POE::Session->create(
     inline_states => {
-      _start => sub { }
+      _start => sub { },
+      _stop  => sub { },
     }
   );
 
@@ -288,8 +302,11 @@ sub check_references {
   my $to_count   = $poe_kernel->_data_ev_get_count_to($session);
   my $check_sum  = $from_count + $to_count + $base_ref;
 
-  ok($check_sum == $ref_count, "refcnts $ref_count == $check_sum $when");
-  ok($from_count == $to_count, "evcount $from_count == $to_count $when");
+  is($check_sum, $ref_count, "refcnts $ref_count == $check_sum $when");
+  is($from_count, $to_count, "evcount $from_count == $to_count $when");
 }
 
+# We created a session, so run it.
+POE::Kernel->run();
+
 1;
